<?php

/**
 * @file
 * Contains functions to alter Drupal's markup for the sector_starter theme.
 *
 * Also see theme-settings.php.
 */

/**
 * Implements hook_field_group_build_pre_render_alter().
 */
function sector_starter_field_group_build_pre_render_alter(&$element) {
  if (!empty($element['#entity_type'])) {
    // Attach a new version of the fieldgroup js, if the entity is a file
    // and a field group with the name "group_transcript_wrapper" exists.
    // This new version extends the existing behaviour with some additional
    // features for showing and hiding a transcript for a video for instance.
    // Important: This file always has to be loaded after the original
    // field_group.js file.
    // as it overrides functionality in the original version.
    $element['#attached']['js'][] = drupal_get_path('theme', 'sector_starter') . '/js/file.field_group.js';
  }
}

/**
 * Implements theme_file_link().
 *
 * Minor changes to override this template, mainly to remove the icon and change
 * the title from displaying the filename to instead display the title.
 */
function sector_starter_file_link($variables) {
  $file = $variables['file'];
  $icon_directory = $variables['icon_directory'];

  $url = file_create_url($file->uri);

  // Set options as per anchor format described at
  // http://microformats.org/wiki/file-format-examples
  $options = array(
    'attributes' => array(
      'type' => $file->filemime . '; length=' . $file->filesize,
    ),
  );

  /*
   * Changes the link text to display the title of the document.
   */
  if (isset($file->field_title['und'][0])) {
    $wrapper = entity_metadata_wrapper('file', $file);
    $link_text = $wrapper->field_title->value();
  }
  else {
    $link_text = $file->filename;
  }

  return '<div class="file__content">' . ' ' . l($link_text, $url, $options) . '</div>';
}

/**
 * Implements template_preprocess_page().
 */
function sector_starter_preprocess_page(&$vars) {

  // Load external Javascript libraries via CDN.
  drupal_add_js('https://cdnjs.cloudflare.com/ajax/libs/respond.js/1.4.2/respond.min.js', 'external');
  drupal_add_js('https://cdnjs.cloudflare.com/ajax/libs/html5shiv/3.7.2/html5shiv.min.js', 'external');
  drupal_add_js('https://maxcdn.bootstrapcdn.com/bootstrap/3.3.4/js/bootstrap.min.js', 'external');

  // Load external Google font.
  drupal_add_css('https://fonts.googleapis.com/css?family=Roboto:700', 'external');

  global $theme;
  // Load custom Javascript and CSS based on the content type.
  if (isset($vars['node'])) {
    switch ($vars['node']->type) {
      case 'resource_multipage_paged':
        // Add JS+CSS for multipage documents.
        drupal_add_js(drupal_get_path('module', 'sector_resource_multipage') . '/js/sector_resource_multipage.js', 'file');
        drupal_add_css(drupal_get_path('theme', $theme) . '/css/sector_resource_multipage.css', 'file');
        break;

      case 'media_collection':
        // Add CSS for media collections.
        drupal_add_css(drupal_get_path('theme', $theme) . '/css/sector_media_collection.css', 'file');
    }
  }

  // Add class to the content wrapper when the sidebar region is present.
  if (!empty($vars['page']['sidebar'])) {
    $vars['content_column_class'] = 'has-sidebar';
  }
  else {
    $vars['content_column_class'] = '';
  }

  // Allow the theme to be given a custom SVG logo.
  $vars['svg_logo_source'] = theme_get_setting('svg_logo_source');
  // Now you can use
  // print($svg_logo_source);
  // in your page.tpl.php.
}

/**
 * Implements hook_preprocess_menu_link().
 */
function sector_starter_preprocess_menu_link(&$variables, $hook) {
  // Borrowed from Zen (https://www.drupal.org/project/zen).
  // Inject BEM-style classes into Drupal menus.
  // Normalise menu item classes to be an array.
  if (empty($variables['element']['#attributes']['class'])) {
    $variables['element']['#attributes']['class'] = array();
  }
  $menu_item_classes =& $variables['element']['#attributes']['class'];
  if (!is_array($menu_item_classes)) {
    $menu_item_classes = array($menu_item_classes);
  }

  // Normalise menu link classes to be an array.
  if (empty($variables['element']['#localized_options']['attributes']['class'])) {
    $variables['element']['#localized_options']['attributes']['class'] = array();
  }
  $menu_link_classes =& $variables['element']['#localized_options']['attributes']['class'];
  if (!is_array($menu_link_classes)) {
    $menu_link_classes = array($menu_link_classes);
  }

  // Add BEM-style classes to the menu item classes.
  $extra_classes = array('menu__item');
  foreach ($menu_item_classes as $key => $class) {
    switch ($class) {
      // Menu module classes.
      case 'expanded':
      case 'collapsed':
      case 'leaf':
      case 'active':
      case 'active-trail':
        $extra_classes[] = 'is-' . $class;
        break;

      case 'has-children':
        $extra_classes[] = 'is-parent';
        break;
    }
  }
  $menu_item_classes = array_merge($extra_classes, $menu_item_classes);

  // Add BEM-style classes to the menu link classes.
  $extra_classes = array('menu__link');
  if (empty($menu_link_classes)) {
    $menu_link_classes = array();
  }
  else {
    foreach ($menu_link_classes as $key => $class) {
      switch ($class) {
        case 'active':
        case 'active-trail':
          $extra_classes[] = 'is-' . $class;
          break;
      }
    }
  }
  $menu_link_classes = array_merge($extra_classes, $menu_link_classes);
}

/**
 * Overrides theme_menu_link().
 */
function sector_starter_menu_link__menu_block($variables) {
  // Remove Bootstrap's menu block link theming, as it breaks the main menu
  // block.
  return theme_menu_link($variables);
}

/**
 * Overrides theme_menu_local_tasks().
 */
function sector_starter_menu_local_tasks(&$variables) {
  $output = '';

  if (!empty($variables['primary'])) {
    $variables['primary']['#prefix'] = '<h2 class="element-invisible">' . t('Primary tabs') . '</h2>';
    $variables['primary']['#prefix'] .= '<ul class="tabs--primary nav nav-pills">';
    $variables['primary']['#suffix'] = '</ul>';
    $output .= drupal_render($variables['primary']);
  }

  if (!empty($variables['secondary'])) {
    $variables['secondary']['#prefix'] = '<h2 class="element-invisible">' . t('Secondary tabs') . '</h2>';
    $variables['secondary']['#prefix'] .= '<ul class="tabs--secondary pagination pagination-sm">';
    $variables['secondary']['#suffix'] = '</ul>';
    $output .= drupal_render($variables['secondary']);
  }

  return $output;
}

/**
 * Implements hook_form_alter().
 */
function sector_starter_form_alter(&$form, &$form_state, $form_id) {
  switch ($form_id) {
    case 'search_block_form':
      // Make the search form accessibility compatible.
      $form['actions']['submit']['#prefix'] = '<label for="edit-submit" class="sr-only">Hidden Submit</label>';
      break;
  }
}

/**
 * Implements hook_preprocess_views_view().
 *
 * For Sector media collection.
 */
function sector_starter_preprocess_views_view(&$vars) {

  global $theme;

  // Load custom JS+CSS files based on view.
  $view = &$vars['view'];
  if ($view->name == 'sector_view_media_collection_single_item' && $view->current_display == 'sector_view_media_collection_single_item_carousel') {
    drupal_add_js(drupal_get_path('module', 'sector_media_collection') . '/js/sector_media_collection.js', 'file');
  }
  elseif ($view->name == 'sector_view_media_collection_single_item' && $view->current_display == 'page') {
    drupal_add_css(drupal_get_path('theme', $theme) . '/css/sector_media_collection.css', 'file');
  }
}

/**
 * Implements template_preprocess_THEME_HOOK().
 *
 * Adding an error class to a Webform element parent/wrapper.
 */
function sector_starter_preprocess_webform_element(&$variables) {
  $element = &$variables['element'];

  $wrapper_classes = array();

  if (isset($element['#parents']) && form_get_error($element)) {
    $wrapper_classes[] = 'error';
  }
  $element['#wrapper_attributes']['class'] = array_merge($element['#wrapper_attributes']['class'], $wrapper_classes);
}

/**
 * Returns HTML for an active facet item.
 *
 * Overridden to enable us to wrap the theme_facetapi_deactivate_widget and
 * associated text within a link.
 */
function sector_starter_facetapi_link_active($variables) {

  // Sanitises the link text if necessary.
  $sanitize = empty($variables['options']['html']);
  $link_text = ($sanitize) ? check_plain($variables['text']) : $variables['text'];

  // Theme function variables fro accessible markup.
  // @see http://drupal.org/node/1316580
  $accessible_vars = array(
    'text' => $variables['text'],
    'active' => TRUE,
  );

  // Builds link, passes through t() which gives us the ability to change the
  // position of the widget on a per-language basis.
  $replacements = array(
    '!facetapi_deactivate_widget' => theme('facetapi_deactivate_widget', $variables),
    '!facetapi_accessible_markup' => theme('facetapi_accessible_markup', $accessible_vars),
  );
  $variables['text'] = t('!facetapi_deactivate_widget !facetapi_accessible_markup', $replacements) . $link_text;
  $variables['options']['html'] = TRUE;
  return theme_link($variables);
}

/**
 * Returns HTML for the deactivation widget.
 *
 * Remove '(-)' and return hidden 'Deactivate facet' text/icon instead.
 */
function sector_starter_facetapi_deactivate_widget($variables) {
  return '<span class="action--deactivate-facet icon--close-small"><span class="sr-only sr-only-focusable">Deactivate facet</span></span>';
}
